==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
var VoidEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VoidEventArgsDescriptionMetadata, _super);
    function VoidEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VoidEventArgsDescriptionMetadata.b = function (a) {
        if (VoidEventArgsDescriptionMetadata.a == null) {
            VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
        }
        if (a.j(VoidEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.c = function (a) {
    };
    VoidEventArgsDescriptionMetadata.d = function (a) {
        VoidEventArgsDescriptionMetadata.b(a);
        a.aa("VoidEventArgs", function () { return new VoidEventArgsDescription(); });
        a.z("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.$t = markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
}(Base));
export { VoidEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
var VoidEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VoidEventArgsDescriptionMetadata, _super);
    function VoidEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VoidEventArgsDescriptionMetadata.b = function (a) {
        if (VoidEventArgsDescriptionMetadata.a == null) {
            VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
        }
        if (a.k(VoidEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    VoidEventArgsDescriptionMetadata.d = function (a) {
        VoidEventArgsDescriptionMetadata.b(a);
        a.ac("VoidEventArgs", function () { return new VoidEventArgsDescription(); });
        a.ab("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
    };
    VoidEventArgsDescriptionMetadata.$t = markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
}(Base));
export { VoidEventArgsDescriptionMetadata };
